<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Sound</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Powiadomienia</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Use sounds</source>
        <translation>Używaj dźwięków</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Zestaw</translation>
    </message>
    <message>
        <source>Sound theme</source>
        <translation>Zestaw dźwięków</translation>
    </message>
    <message>
        <source>Sound paths</source>
        <translation>Ścieżki do zestawów</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>Głośność</translation>
    </message>
    <message>
        <source>Enable volume control (player must support it)</source>
        <translation>Włącz kontrolę głośności (musi być wspierana przez odtwarzacz)</translation>
    </message>
    <message>
        <source>Samples</source>
        <translation>Testy</translation>
    </message>
    <message>
        <source>Test sample playing</source>
        <translation>Test odtwarzania</translation>
    </message>
    <message>
        <source>Test sample recording</source>
        <translation>Test nagrywania</translation>
    </message>
    <message>
        <source>Test full duplex</source>
        <translation>Test pełnego dupleksu (odtwarzania i nagrywanie)</translation>
    </message>
</context>
<context>
    <name>SoundConfigurationWidget</name>
    <message>
        <source>Choose &apos;Custom&apos; theme in &apos;Sound&apos; page to change sound file</source>
        <translation>Wybierz zestaw &apos;Własne&apos; na stronie &apos;Dźwięk&apos; aby zmieniać plik dźwiękowy</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Sound file</source>
        <translation>Plik dźwiękowy</translation>
    </message>
</context>
<context>
    <name>SoundManager</name>
    <message>
        <source>Custom</source>
        <translation>Własne</translation>
    </message>
</context>
<context>
    <name>SoundSlots</name>
    <message>
        <source>Unmute sounds</source>
        <translation>Przywróć dźwięki</translation>
    </message>
    <message>
        <source>Mute sounds</source>
        <translation>Wyłącz dźwięki</translation>
    </message>
    <message>
        <source>Opening test sample file failed.</source>
        <translation>Otwarcie pliku testowego nieudane.</translation>
    </message>
    <message>
        <source>Reading test sample file failed.</source>
        <translation>Czytanie pliku testowego nieudane.</translation>
    </message>
    <message>
        <source>Opening sound device failed.</source>
        <translation>Otwarcie urządzenia dźwięku nieudane.</translation>
    </message>
    <message>
        <source>Testing sample playing. You should hear some sound now.</source>
        <translation>Test odtwarzania dźwięku. Powinien on być teraz słyszalny.</translation>
    </message>
    <message>
        <source>Testing sample recording. Please talk now (3 seconds).</source>
        <translation>Test nagrywania. Proszę mówić przez 3 sekundy.</translation>
    </message>
    <message>
        <source>You should hear your recorded sample now.</source>
        <translation>Nagrany dźwięk powinien być teraz słyszalny.</translation>
    </message>
    <message>
        <source>Testing fullduplex. Please talk now.
You should here it with one second delay.</source>
        <translation>Test full dupleksu. Proszę teraz mówić. Dźwięk powinien
być słyszalny z 1 sekundowym opóźnieniem.</translation>
    </message>
    <message>
        <source>Cannot open sound device for playing!</source>
        <translation>Nie mogę otworzyć urządzenia dźwiękowego do odtwarzania!</translation>
    </message>
</context>
</TS>
